"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var react_1 = require("react");
var actions_1 = require("@shopify/app-bridge/actions");
var globals_1 = require("./globals");
function useRoutePropagation(app, location) {
    var history = react_1.useMemo(function () { return actions_1.History.create(app); }, [app]);
    react_1.useEffect(function () {
        var selfWindow = globals_1.getSelfWindow();
        var topWindow = globals_1.getTopWindow();
        var renderedInTheTopWindow = selfWindow === topWindow;
        var renderedInAModal = selfWindow.name === globals_1.MODAL_IFRAME_NAME;
        if (renderedInTheTopWindow || renderedInAModal) {
            return;
        }
        var normalizedLocation = getNormalizedURL(location);
        /*
          We delete this param that ends up unnecassarily stuck on
          the iframe due to oauth when propagating up.
        */
        normalizedLocation.searchParams.delete('hmac');
        var pathname = normalizedLocation.pathname, search = normalizedLocation.search, hash = normalizedLocation.hash;
        var locationStr = "" + pathname + search + hash;
        history.dispatch(actions_1.History.Action.REPLACE, locationStr);
    }, [history, location]);
}
exports.default = useRoutePropagation;
function getNormalizedURL(location) {
    var origin = globals_1.getOrigin();
    if (typeof location === 'string') {
        return new URL(location, origin);
    }
    var pathname = location.pathname, search = location.search, hash = location.hash;
    return new URL("" + pathname + search + hash, origin);
}
